@@ -1,4 +1,4 @@
-// Copyright © 2016–2021 Trevor Spiteri
+// Copyright © 2016–2022 Trevor Spiteri
 
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -420,6 +420,34 @@ arith_prim_exact_round! {
     ShrAssign { shr_assign }
     i32, ShrI32Incomplete;
 }
+arith_prim_exact_round! {
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
+    xmpc::shl_usize;
+    Shl { shl }
+    ShlAssign { shl_assign }
+    usize, ShlUsizeIncomplete;
+}
+arith_prim_exact_round! {
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
+    xmpc::shr_usize;
+    Shr { shr }
+    ShrAssign { shr_assign }
+    usize, ShrUsizeIncomplete;
+}
+arith_prim_exact_round! {
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
+    xmpc::shl_isize;
+    Shl { shl }
+    ShlAssign { shl_assign }
+    isize, ShlIsizeIncomplete;
+}
+arith_prim_exact_round! {
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
+    xmpc::shr_isize;
+    Shr { shr }
+    ShrAssign { shr_assign }
+    isize, ShrIsizeIncomplete;
+}
 
 mul_op_commut_round! {
     Complex, (u32, u32), Round2, NEAREST2, Ordering2;
@@ -876,4 +904,21 @@ mod tests {
 
         float::free_cache(FreeCache::All);
     }
+
+    #[test]
+    fn check_shift_u_s() {
+        let c = &Complex::with_val(53, (13.75, -1.92e-10));
+
+        assert_eq!(c.clone() << 10u32, c.clone() << 10i32);
+        assert_eq!(c.clone() << 10u32, c.clone() >> -10i32);
+        assert_eq!(c.clone() >> 10u32, c.clone() >> 10i32);
+        assert_eq!(c.clone() >> 10u32, c.clone() << -10i32);
+
+        assert_eq!(c.clone() << 10u32, c.clone() << 10usize);
+        assert_eq!(c.clone() << 10u32, c.clone() << 10isize);
+        assert_eq!(c.clone() << 10u32, c.clone() >> -10isize);
+        assert_eq!(c.clone() >> 10u32, c.clone() >> 10usize);
+        assert_eq!(c.clone() >> 10u32, c.clone() >> 10isize);
+        assert_eq!(c.clone() >> 10u32, c.clone() << -10isize);
+    }
 }
