@@ -1,4 +1,4 @@
-// Copyright © 2016–2021 Trevor Spiteri
+// Copyright © 2016–2022 Trevor Spiteri
 
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -309,6 +309,34 @@ unsafe_wrap! { fn shl_i32(op1: O; op2: i32) -> mpc::mul_2si }
 unsafe_wrap! { fn shr_i32(op1: O; op2: i32) -> mpc::div_2si }
 unsafe_wrap! { fn shl_u32(op1: O; op2: u32) -> mpc::mul_2ui }
 unsafe_wrap! { fn shr_u32(op1: O; op2: u32) -> mpc::div_2ui }
+unsafe_wrap! { fn shl_isize(op1: O; op2: isize) -> mul_2isize }
+unsafe_wrap! { fn shr_isize(op1: O; op2: isize) -> div_2isize }
+unsafe_wrap! { fn shl_usize(op1: O; op2: usize) -> mul_2usize }
+unsafe_wrap! { fn shr_usize(op1: O; op2: usize) -> div_2usize }
+
+#[inline]
+unsafe fn mul_2isize(rop: *mut mpc_t, op1: *const mpc_t, op2: isize, rnd: rnd_t) -> c_int {
+    let op2 = op2.unwrapped_cast();
+    unsafe { mpc::mul_2si(rop, op1, op2, rnd) }
+}
+
+#[inline]
+unsafe fn div_2isize(rop: *mut mpc_t, op1: *const mpc_t, op2: isize, rnd: rnd_t) -> c_int {
+    let op2 = op2.unwrapped_cast();
+    unsafe { mpc::div_2si(rop, op1, op2, rnd) }
+}
+
+#[inline]
+unsafe fn mul_2usize(rop: *mut mpc_t, op1: *const mpc_t, op2: usize, rnd: rnd_t) -> c_int {
+    let op2 = op2.unwrapped_cast();
+    unsafe { mpc::mul_2ui(rop, op1, op2, rnd) }
+}
+
+#[inline]
+unsafe fn div_2usize(rop: *mut mpc_t, op1: *const mpc_t, op2: usize, rnd: rnd_t) -> c_int {
+    let op2 = op2.unwrapped_cast();
+    unsafe { mpc::div_2ui(rop, op1, op2, rnd) }
+}
 
 #[inline]
 pub fn write_new_nan(dst: &mut MaybeUninit<Complex>, prec_real: prec_t, prec_imag: prec_t) {
