@@ -1,4 +1,4 @@
-// Copyright © 2016–2021 Trevor Spiteri
+// Copyright © 2016–2022 Trevor Spiteri
 
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -405,6 +405,34 @@ arith_prim_exact_round! {
     ShrAssign { shr_assign }
     i32, ShrI32Incomplete;
 }
+arith_prim_exact_round! {
+    Float, u32, Round, Round::Nearest, Ordering;
+    xmpfr::shl_usize;
+    Shl { shl }
+    ShlAssign { shl_assign }
+    usize, ShlUsizeIncomplete;
+}
+arith_prim_exact_round! {
+    Float, u32, Round, Round::Nearest, Ordering;
+    xmpfr::shr_usize;
+    Shr { shr }
+    ShrAssign { shr_assign }
+    usize, ShrUsizeIncomplete;
+}
+arith_prim_exact_round! {
+    Float, u32, Round, Round::Nearest, Ordering;
+    xmpfr::shl_isize;
+    Shl { shl }
+    ShlAssign { shl_assign }
+    isize, ShlIsizeIncomplete;
+}
+arith_prim_exact_round! {
+    Float, u32, Round, Round::Nearest, Ordering;
+    xmpfr::shr_isize;
+    Shr { shr }
+    ShrAssign { shr_assign }
+    isize, ShrIsizeIncomplete;
+}
 mul_op_commut_round! {
     Float, u32, Round, Round::Nearest, Ordering;
     add_mul;
@@ -840,4 +868,34 @@ pub(crate) mod tests {
 
         float::free_cache(FreeCache::All);
     }
+
+    #[test]
+    fn check_shift_u_s() {
+        let pos = &Float::with_val(53, 13.75);
+        let neg = &Float::with_val(53, -1.92e-10);
+
+        assert_eq!(pos.clone() << 10u32, pos.clone() << 10i32);
+        assert_eq!(pos.clone() << 10u32, pos.clone() >> -10i32);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() >> 10i32);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() << -10i32);
+
+        assert_eq!(neg.clone() << 10u32, neg.clone() << 10i32);
+        assert_eq!(neg.clone() << 10u32, neg.clone() >> -10i32);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() >> 10i32);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() << -10i32);
+
+        assert_eq!(pos.clone() << 10u32, pos.clone() << 10usize);
+        assert_eq!(pos.clone() << 10u32, pos.clone() << 10isize);
+        assert_eq!(pos.clone() << 10u32, pos.clone() >> -10isize);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() >> 10usize);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() >> 10isize);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() << -10isize);
+
+        assert_eq!(neg.clone() << 10u32, neg.clone() << 10usize);
+        assert_eq!(neg.clone() << 10u32, neg.clone() << 10isize);
+        assert_eq!(neg.clone() << 10u32, neg.clone() >> -10isize);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() >> 10usize);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() >> 10isize);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() << -10isize);
+    }
 }
