@@ -1,4 +1,4 @@
-// Copyright © 2016–2021 Trevor Spiteri
+// Copyright © 2016–2022 Trevor Spiteri
 
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -286,6 +286,34 @@ arith_prim! {
     ShrAssign { shr_assign }
     u32, ShrU32Incomplete;
 }
+arith_prim! {
+    Integer;
+    xmpz::shl_isize;
+    Shl { shl }
+    ShlAssign { shl_assign }
+    isize, ShlIsizeIncomplete;
+}
+arith_prim! {
+    Integer;
+    xmpz::shr_isize;
+    Shr { shr }
+    ShrAssign { shr_assign }
+    isize, ShrIsizeIncomplete;
+}
+arith_prim! {
+    Integer;
+    xmpz::shl_usize;
+    Shl { shl }
+    ShlAssign { shl_assign }
+    usize, ShlUsizeIncomplete;
+}
+arith_prim! {
+    Integer;
+    xmpz::shr_usize;
+    Shr { shr }
+    ShrAssign { shr_assign }
+    usize, ShrUsizeIncomplete;
+}
 arith_prim! {
     Integer;
     xmpz::pow_u32;
@@ -713,7 +741,31 @@ mod tests {
     fn check_shift_u_s() {
         let pos = &(Integer::from(11) << 100u32);
         let neg = &(Integer::from(-33) << 50u32);
-        assert_eq!(pos.clone() << 10, pos.clone() >> -10);
+
+        assert_eq!(pos.clone() << 10u32, pos.clone() << 10i32);
+        assert_eq!(pos.clone() << 10u32, pos.clone() >> -10i32);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() >> 10i32);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() << -10i32);
+
+        assert_eq!(neg.clone() << 10u32, neg.clone() << 10i32);
+        assert_eq!(neg.clone() << 10u32, neg.clone() >> -10i32);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() >> 10i32);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() << -10i32);
+
+        assert_eq!(pos.clone() << 10u32, pos.clone() << 10usize);
+        assert_eq!(pos.clone() << 10u32, pos.clone() << 10isize);
+        assert_eq!(pos.clone() << 10u32, pos.clone() >> -10isize);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() >> 10usize);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() >> 10isize);
+        assert_eq!(pos.clone() >> 10u32, pos.clone() << -10isize);
+
+        assert_eq!(neg.clone() << 10u32, neg.clone() << 10usize);
+        assert_eq!(neg.clone() << 10u32, neg.clone() << 10isize);
+        assert_eq!(neg.clone() << 10u32, neg.clone() >> -10isize);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() >> 10usize);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() >> 10isize);
+        assert_eq!(neg.clone() >> 10u32, neg.clone() << -10isize);
+
         assert_eq!(pos.clone() << 10, Integer::from(11) << 110);
         assert_eq!(pos.clone() << -100, pos.clone() >> 100);
         assert_eq!(pos.clone() << -100, 11);
