@@ -1,4 +1,4 @@
-// Copyright © 2016–2021 Trevor Spiteri
+// Copyright © 2016–2022 Trevor Spiteri
 
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -42,6 +42,8 @@ pub(crate) mod big;
 mod casts;
 mod cmp;
 mod division;
+#[cfg(feature = "num-traits")]
+mod impl_num_traits;
 #[cfg(feature = "serde")]
 mod serde;
 pub(crate) mod small;
