@@ -1,4 +1,4 @@
-// Copyright © 2016–2021 Trevor Spiteri
+// Copyright © 2016–2022 Trevor Spiteri
 
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -476,6 +476,7 @@ pub trait ShrFrom<Lhs = Self> {
     fn shr_from(&mut self, lhs: Lhs);
 }
 
+#[cfg(not(feature = "num-traits"))]
 /**
 The power operation.
 
@@ -512,6 +513,10 @@ pub trait Pow<Rhs> {
     fn pow(self, rhs: Rhs) -> Self::Output;
 }
 
+#[cfg(feature = "num-traits")]
+#[doc(inline)]
+pub use num_traits_crate::pow::Pow;
+
 /**
 Compound power operation and assignment.
 
